pub enum ComponentAccessError {
NotRegistered {
resource: &'static str,
operation: &'static str,
},
ReadConflict {
resource: &'static str,
operation: &'static str,
},
WriteConflict {
resource: &'static str,
operation: &'static str,
},
}Expand description
Failure to acquire access to component state.
A conflict identifies the requested access, not the holder or its call stack. Callback reentry can cause a conflict, but is not the only possible cause.
Variants
NotRegistered
Registration has not supplied the requested resource.
Fields
ReadConflict
Shared access conflicts with an existing exclusive borrow.
Fields
WriteConflict
Exclusive access conflicts with an existing shared or exclusive borrow.